# Требования к результату

## Технические требования

* Программный код всех модулей должен быть оформлен в соответствии со стандартами разработки на платформе 1С:Предприятие по ссылке: https://its.1c.ru/db/v8std#content:456:hdoc

* Недопустимо выполнять запросы в цикле, в том числе неявные при обращении через точку к реквизиту ссылки. То есть обращение `Строка.Номенклатура.ТипНоменклатуры` недопустимо.

* При работе с регистрами расчета необходимо получать данные для расчета через виртуальные таблицы. Недопустимо использовать объектную модель для обращения к регистрам расчета.

## Функциональные требования

Выгрузка информационной базы (файл с расширением dt), включающий демоданные и конфигурацию с именем "УправлениеИТФирмой" из диплома блока Б, дополненную:

Подсистемой **Учет**, а в ней:

* Регистром бухгалтерии **Управленческий**, который:
  * Содержит ресурсы Количество и Сумма определяемых типов
  * Поддерживает корреспонденции
   
* Планом видов характеристик **ВидыСубконто**, который:
  * Включает значения типов СправочникСсылка.Номенклатура, СправочникСсылка.Контрагенты, СправочникСсылка.Сотрудники
  * Содержит предопределенные элементы Номенклатура, Контрагенты, Сотрудники

* Планом счетов **Управленческий**, который:
  * Используется для учета в регистре бухгалтерии **Управленческий**
  * В качестве видов субконто использует ПВХ **ВидыСубконто**
  * Содержит предопределенные счета:
    * Активный 41 **Товары** (виды субконто: Номенклатура, учет по количеству)
    * Активный 50 **ДенежныеСредства**
    * Пассивный 60 **РасчетыСПоставщиками** (виды субконто: Контрагенты)
    * Активный 62 **РасчетыСПокупателями** (виды субконто: Контрагенты)
    * Активно-пассивный 70 **РасчетыССотрудниками** (виды субконто: Сотрудники)
    * Активно-пассивный 90 **ПрибылиИУбытки** с субсчетами
      * 90.1 **Доходы**
      * 90.2 **Расходы**
      
* Отчетом **ОборотноСальдоваяВедомость**, который:
  * Построен на СКД
  * Выводит отстатки и обороты по счетам за выбранный период

* Документы, созданные в рамках диплома Б, должны быть доработаны для формирования проводок по регистру бухгалтерии **Управленческий**:
  * Документ **ПоступлениеТоваровИУслуг**:
    * Для товаров - Дт **Товары** с заполнением субконто Номенклатура - Кт **РасчетыСПоставщиками** с заполнением субконто Контрагенты на сумму закупки.
    * Для услуг - Дт **Расходы** - Кт **РасчетыСПоставщиками** с заполнением субконто Контрагенты на сумму закупки.
  * Документ **РеализацияТоваровИУслуг**:
    * Для всех строк - Дт **РасчетыСПокупателями** с заполнением субконто Контрагенты - Кт **Доходы** на сумму продажи.
    * Для товаров - Дт **Расходы** - Кт **Товары** с заполнением субконто Номенклатура на сумму себестоимости списанного товара. Себестоимость должна рассчитываться по данным регистра бухгалтерии, а не по данным регистра накопления **Товары**. Недопустимо списание товара в минус.
  * Документ **ПоступлениеДенежныхСредств** (после расширения типа реквизита **Плательщик** типом **СправочникСсылка.Сотрудники**):
    * Для контрагентов - Дт **ДенежныеСредства** - Кт **РасчетыСПокупателями** с заполнением субконто **Контрагенты** на сумму платежа.
    * Для сотрудников - Дт **ДенежныеСредства** - Кт **РасчетыССотрудниками** с заполнением субконто **Сотрудники** на сумму платежа.
  * Документом **СписаниеДенежныхСредств** (после расширения типа реквизита **Получатель** типом **СправочникСсылка.Сотрудники**):
    * Для контрагентов - Дт **РасчетыСПоставщиками** с заполнением субконто **Контрагенты** - Кт **ДенежныеСредства** на сумму платежа.
    * Для сотрудников - Дт **РасчетыССотрудниками** с заполнением субконто **Сотрудники** - Кт **ДенежныеСредства** на сумму платежа.

Подсистемой **Зарплата**, а в ней:

* Регистром сведений **Календарь**, который:
  * Содержит измерение **День** (Дата) и ресурс **Рабочий** (Число)

* Регистром расчета **Зарплата**, который:
  * Содержит измерение **Сотрудник** и ресурс **Сумма** определяемого типа
  * Поддерживает период действия и период регистрации
  * Привязан к регистру **Календарь** как к календарю
   
* Планом видов расчета **Начисления**, который:
  * Используется для учета в регистре расчета **Зарплата**
  * Использует период действия и зависит по базе по периоду действия от самого себя.
  * Содержит предопределенные виды расчетов:
    * Больничный, Отпуск, ФиксированнаяПремия
    * ОплатаПоОкладу, вытесняемый видами расчета Больничный и Отпуск
    * ПремияПроцентом, зависящая по базе от вида расчета ОплатаПоОкладу
      
* Документом **НачислениеСписком**, который:
  * Содержит реквизит **Начисление** (ПланВидовРасчетаСсылка.Начисления) и начало и конец периода действия
  * Содержит табличную часть **Сотрудники** с сотрудниками и суммами
  * При проведении формирует движения:
    * По регистру расчета **Зарплата** с указанием сотрудника, вида расчета, периодов и суммы
    * По регистру бухгалтерии **Управленческий** в Дт счета **Расходы** с Кт счета **РасчетыССотрудниками** с заполнением субконто **Сотрудники** на ту же сумму.

* Документом **НачислениеОплатыПоОкладу**, который:
  * Содержит реквизит **ЗаМесяц** (Дата), определяющий месяц периода действия
  * Содержит табличную часть **Сотрудники** с сотрудниками
  * При проведении формирует движения:
    * По регистру расчета **Зарплата** с указанием сотрудника, вида расчета, периодов и суммы. Сумма рассчитывается по данным графиков как оклад, умноженный на частное от деления фактически отработанного времени (с учетом вытеснения больничным и окладом) на норму времени.
    * По регистру бухгалтерии **Управленческий** в Дт счета **Расходы** с Кт счета **РасчетыССотрудниками** с заполнением субконто **Сотрудники** на ту же сумму.    
    
* Документом **НачислениеПремииПроцентом**, который:
  * Содержит реквизит **ЗаМесяц** (Дата), определяющий месяц периода действия, и **Процент** (Число), определяющий процент премии
  * Содержит табличную часть **Сотрудники** с сотрудниками
  * При проведении формирует движения:
    * По регистру расчета **Зарплата** с указанием сотрудника, вида расчета, периодов и суммы. Сумма рассчитывается по данным базы (оплаты по окладу за базовый период) умножением базы на процент.
    * По регистру бухгалтерии **Управленческий** в Дт счета **Расходы** с Кт счета **РасчетыССотрудниками** с заполнением субконто **Сотрудники** на ту же сумму.

Подсистемой **Взаимодействие**, а в ней:

* Справочником **Роли** с наименованием разумной длины

* Регистром сведений **ИсполнителиРолей**, который:
  * Содержит измерения **Роль** (СправочникСсылка.Роли) и **Исполнитель** (СправочникСсылка.Сотрудники)
  * Используется для адресации задач

* Задачей **Задача**, которая:
  * Содержит реквизиты адресации **Исполнитель** (основной, СправочникСсылка.Сотрудники) и **Роль** (СправочникСсылка.Роли), заполняемые по данным процесса
  * В качестве текущего исполнителя использует значение параметра сеанса **ТекущийСотрудник**
  * Содержит реквизит **ПодробноеОписание** (строка неограниченной длины), заполняемый по данным процесса
  * Содержит форму задачи с ее прикладными реквизитами, недоступными для редактирования
  * Содержит форму **ЗадачиМне**, которая:
    * Содержит задачи, адресованные текущему сотруднику по данным виртуальной таблицы **Задача.Задача.ЗадачиПоИсполнителю** с учетом ролевой адресации
    * Выведена на рабочую область начальной страницы

* Процессом **Поручение**, который:
  * Использует задачу **Задача**
  * Содержит реквизиты, достаточные для заполнения создаваемых задач, и реквизит **Предмет** (ОпределяемыйТип.ПредметПроцесса)
  * Имеет простую схему, состоящую из точки старта, точки действия и точки завершения
  * При создании задач заполняет их наименование, подробное описание, исполнителя и роль по собственным данным
